// Copyright 1997-2000 Omni Development, Inc.  All rights reserved.
//
// This software may only be used and reproduced according to the
// terms in the file OmniSourceLicense.html, which should be
// distributed with this project and can also be found at
// http://www.omnigroup.com/DeveloperResources/OmniSourceLicense.html.
//
// $Header: /Network/Source/CVS/OmniGroup/Frameworks/OmniFoundation/Attic/OFUserDefaults.h,v 1.15 2000/01/30 22:44:07 kc Exp $

// Don't try to read defaults in +didLoad, they might not be registered yet.  In +didLoad, register for OFControllerDidInitNotification, then read defaults when that's posted.

#import <OmniFoundation/OFObject.h>

@class NSMutableArray, NSArray, NSData;

@interface OFUserDefaults : OFObject
{
    NSString *ownerName;
    NSMutableArray *unresolvedKeys;
    NSMutableDictionary *argumentDictionary;
    NSMutableDictionary *defaultsDictionary;
    NSMutableDictionary *globalDefaultsDictionary;
    NSMutableDictionary *registrationDictionary;
    NSMutableDictionary *overrideNetworkDictionary;
    NSMutableDictionary *advisoryNetworkDictionary;
    unsigned int changeCount;
}

+ (NSString *)sharedUserDefaultsOwnerName;
    // Applications that wish to share their user defaults with other applications can override this to return a common defaults owner name.
+ (OFUserDefaults *)sharedUserDefaults;

- (void)setOwnerName:(NSString *)ownerName;
    // NOTE: You cannot change the owner name on the fly in the current implementation, so, really, this method isn't very useful as public API.  The +sharedUserDefaultsOwnerName method is as close as it gets, right now.
- (NSString *)ownerName;

- (void)readDefaultsDatabase;

- (NSDictionary *)argumentDictionary;
- (NSDictionary *)defaultsDictionary;
- (NSDictionary *)registrationDictionary;
- (NSDictionary *)overrideNetworkDictionary;
- (NSDictionary *)advisoryNetworkDictionary;
- (unsigned int)changeCount;

- (BOOL)defaultRegisteredForKey:(NSString *)defaultName;
- (id)objectForKey:(NSString *)defaultName;

- (NSArray *)arrayForKey:(NSString *)defaultName;
- (BOOL)boolForKey:(NSString *)defaultName;
- (NSData *)dataForKey:(NSString *)defaultName;
- (NSDictionary *)dictionaryForKey:(NSString *)defaultName;
- (float)floatForKey:(NSString *)defaultName;
- (int)integerForKey:(NSString *)defaultName;
- (NSArray *)stringArrayForKey:(NSString *)defaultName;
- (NSString *)stringForKey:(NSString *)defaultName;

- (void)removeObjectForKey:(NSString *)defaultName;

- (void)setObject:(id)value forKey:(NSString *)defaultName;

- (void)setBool:(BOOL)value forKey:(NSString *)defaultName;
- (void)setFloat:(float)value forKey:(NSString *)defaultName;
- (void)setInteger:(int)value forKey:(NSString *)defaultName;

- (void)registerDefaults:(NSDictionary *)dictionary;	

@end

#import <OmniFoundation/FrameworkDefines.h>

OmniFoundation_EXTERN NSString *OFUserDefaultsNotRegisteredException;
